==> llm_workflow_engine-0.22.11.tar.gz: llm_workflow_engine-0.22.11/README.md <==
[![Test status](https://github.com/llm-workflow-engine/llm-workflow-engine/actions/workflows/python-app.yml/badge.svg)](https://github.com/llm-workflow-engine/llm-workflow-engine/actions/workflows/python-app.yml)
[![CodeQL](https://github.com/llm-workflow-engine/llm-workflow-engine/actions/workflows/github-code-scanning/codeql/badge.svg)](https://github.com/llm-workflow-engine/llm-workflow-engine/actions/workflows/github-code-scanning/codeql)

<p align="center">
  <img alt="lwe-logo-small" src="https://github.com/llm-workflow-engine/llm-workflow-engine/assets/43772/6921deac-0964-41a9-84fd-7c2ebce198c0" />
</p>

<h1>
  <p align="center">
    LLM Workflow Engine
  </p>
</h1>

<p id="summary-header" align="center">LLM Workflow Engine (LWE) is a <b>Power CLI</b> and <b>Workflow manager</b> for LLMs.</p>

<h4 id="documentation" align="center">
  <a href="https://llm-workflow-engine.readthedocs.io" target="_blank">
    Read the documentation
  </a>
</h4>

<h4 id="intro-video" align="center">
  <a href="https://www.youtube.com/watch?v=-FiYQiS5nY4" target="_blank">
    WATCH INTRO VIDEO
  </a>
</h4>

## Welcome!

What would you like to do?

* [Learn about the project](https://llm-workflow-engine.readthedocs.io)
* [Install LWE](https://llm-workflow-engine.readthedocs.io/en/latest/installation.html)
* [Learn how to use it](https://llm-workflow-engine.readthedocs.io/en/latest/how_it_works.html)
* [Read the documentation](https://llm-workflow-engine.readthedocs.io)
* [Learn more about configuration/features](https://llm-workflow-engine.readthedocs.io/en/latest/configuration.html)
* [Troubleshoot common issues](https://llm-workflow-engine.readthedocs.io/en/latest/troubleshooting.html)
* [Upgrade LWE](https://llm-workflow-engine.readthedocs.io/en/latest/upgrading.html)
* [Using GPT4](https://llm-workflow-engine.readthedocs.io/en/latest/model_access.html#gpt4)
* [Report a bug](ISSUES.md)
* [Get support](SUPPORT.md)


## What happend to the original ChatGPT Wrapper project?

See [CHATGPT_WRAPPER.md](CHATGPT_WRAPPER.md)

ChatGPT Wrapper was an amazing tool for its time, thank you to its original creator [mmabrouk](https://github.com/mmabrouk) for all your hard work, it lives on in a new form :)

## Highlights

🤖 LWE lets you use the powerful ChatGPT/GPT4 bot from the **command line**.

💬 **Runs in Shell**. You can call and interact with ChatGPT/GPT4 in the terminal.

💻  **Supports official ChatGPT API**. Make API calls directly to the OpenAI ChatGPT endpoint (all supported models accessible by your OpenAI account)

🔌 [**Simple plugin architecture**](https://llm-workflow-engine.readthedocs.io/en/latest/plugins.html#core-plugins). Extend LWE with custom functionality

🗣 **Supports multiple LLM providers**. Provider plugins allow interacting with other LLMs (GPT-3, Cohere, Hugginface, etc.)

🔄[**Build workflows**](https://llm-workflow-engine.readthedocs.io/en/latest/workflows.html). Easily integrate calls to an LLM into larger workflows via Ansible Playbooks

🔧 [**Tool use**](https://llm-workflow-engine.readthedocs.io/en/latest/tools.html). (for supported providers)

🐳 **Docker image**. LWE is also available as a docker image. (experimental)

🐍**Python API**. LWE also has a Python library that lets you use ChatGPT/GPT4 in your Python scripts.

## Projects built with the original ChatGPT Wrapper

- [bookast: ChatGPT Podcast Generator For Books](https://github.com/SamMethnani/bookast)
- [ChatGPT.el: ChatGPT in Emacs](https://github.com/joshcho/ChatGPT.el)
- [ChatGPT Reddit Bot](https://github.com/PopDaddyGames/ChatGPT-RedditBot)
- [Smarty GPT](https://github.com/citiususc/Smarty-GPT/tree/v1.1.0)
- [ChatGPTify](https://github.com/idilsulo/ChatGPTify)
- [selection-to-chatgpt](https://github.com/collin-murphy/selection-to-chatgpt)

## Contributing

We welcome contributions to LWE! If you have an idea for a new feature or have found a bug, please open an issue on the GitHub repository.

## License

This project is licensed under the MIT License - see the LICENSE file for details.

## Acknowledgments

- The original ChatGPT Wrapper project (which LWE grew from) was created and maintained by [mmabrouk](https://github.com/mmabrouk) 
- The original ChatGPT Wrapper project is a modification from [Taranjeet](https://github.com/taranjeet/chatgpt-api) code which is a modification of [Daniel Gross](https://github.com/danielgross/whatsapp-gpt) code.

## Star History

[![Star History Chart](https://api.star-history.com/svg?repos=llm-workflow-engine/llm-workflow-engine&type=Date)](https://star-history.com/#llm-workflow-engine/llm-workflow-engine&Date)

==> llm_workflow_engine-0.22.13.tar.gz: llm_workflow_engine-0.22.13/README.md <==
[![Test status](https://github.com/llm-workflow-engine/llm-workflow-engine/actions/workflows/python-app.yml/badge.svg)](https://github.com/llm-workflow-engine/llm-workflow-engine/actions/workflows/python-app.yml)
[![CodeQL](https://github.com/llm-workflow-engine/llm-workflow-engine/actions/workflows/github-code-scanning/codeql/badge.svg)](https://github.com/llm-workflow-engine/llm-workflow-engine/actions/workflows/github-code-scanning/codeql)

<p align="center">
  <img alt="lwe-logo-small" src="https://github.com/llm-workflow-engine/llm-workflow-engine/assets/43772/6921deac-0964-41a9-84fd-7c2ebce198c0" />
</p>

<h1>
  <p align="center">
    LLM Workflow Engine
  </p>
</h1>

<p id="summary-header" align="center">LLM Workflow Engine (LWE) is a <b>Power CLI</b> and <b>Workflow manager</b> for LLMs.</p>

<h4 id="documentation" align="center">
  <a href="https://llm-workflow-engine.readthedocs.io" target="_blank">
    Read the documentation
  </a>
</h4>

<h4 id="intro-video" align="center">
  <a href="https://www.youtube.com/watch?v=-FiYQiS5nY4" target="_blank">
    WATCH INTRO VIDEO
  </a>
</h4>

## Welcome!

What would you like to do?

* [Learn about the project](https://llm-workflow-engine.readthedocs.io)
* [Install LWE](https://llm-workflow-engine.readthedocs.io/en/latest/installation.html)
* [Learn how to use it](https://llm-workflow-engine.readthedocs.io/en/latest/how_it_works.html)
* [Read the documentation](https://llm-workflow-engine.readthedocs.io)
* [Learn more about configuration/features](https://llm-workflow-engine.readthedocs.io/en/latest/configuration.html)
* [Troubleshoot common issues](https://llm-workflow-engine.readthedocs.io/en/latest/troubleshooting.html)
* [Upgrade LWE](https://llm-workflow-engine.readthedocs.io/en/latest/upgrading.html)
* [Using GPT4](https://llm-workflow-engine.readthedocs.io/en/latest/model_access.html#gpt4)
* [Report a bug](ISSUES.md)
* [Get support](SUPPORT.md)


## What happend to the original ChatGPT Wrapper project?

See [CHATGPT_WRAPPER.md](CHATGPT_WRAPPER.md)

ChatGPT Wrapper was an amazing tool for its time, thank you to its original creator [mmabrouk](https://github.com/mmabrouk) for all your hard work, it lives on in a new form :)

## Highlights

🤖 LWE lets you use the powerful ChatGPT/GPT4 bot from the **command line**.

💬 **Runs in Shell**. You can call and interact with ChatGPT/GPT4 in the terminal.

💻  **Supports official ChatGPT API**. Make API calls directly to the OpenAI ChatGPT endpoint (all supported models accessible by your OpenAI account)

🔌 [**Simple plugin architecture**](https://llm-workflow-engine.readthedocs.io/en/latest/plugins.html#core-plugins). Extend LWE with custom functionality

🗣 **Supports multiple LLM providers**. Provider plugins allow interacting with other LLMs (GPT-3, Cohere, Huggingface, etc.)

🔄[**Build workflows**](https://llm-workflow-engine.readthedocs.io/en/latest/workflows.html). Easily integrate calls to an LLM into larger workflows via Ansible Playbooks

🔧 [**Tool use**](https://llm-workflow-engine.readthedocs.io/en/latest/tools.html). (for supported providers)

🐳 **Docker image**. LWE is also available as a docker image. (experimental)

🐍**Python API**. LWE also has a Python library that lets you use ChatGPT/GPT4 in your Python scripts.

## Projects built with the original ChatGPT Wrapper

- [bookast: ChatGPT Podcast Generator For Books](https://github.com/SamMethnani/bookast)
- [ChatGPT.el: ChatGPT in Emacs](https://github.com/joshcho/ChatGPT.el)
- [ChatGPT Reddit Bot](https://github.com/PopDaddyGames/ChatGPT-RedditBot)
- [Smarty GPT](https://github.com/citiususc/Smarty-GPT/tree/v1.1.0)
- [ChatGPTify](https://github.com/idilsulo/ChatGPTify)
- [selection-to-chatgpt](https://github.com/collin-murphy/selection-to-chatgpt)

## Contributing

We welcome contributions to LWE! If you have an idea for a new feature or have found a bug, please open an issue on the GitHub repository.

## License

This project is licensed under the MIT License - see the LICENSE file for details.

## Acknowledgments

- The original ChatGPT Wrapper project (which LWE grew from) was created and maintained by [mmabrouk](https://github.com/mmabrouk) 
- The original ChatGPT Wrapper project is a modification from [Taranjeet](https://github.com/taranjeet/chatgpt-api) code which is a modification of [Daniel Gross](https://github.com/danielgross/whatsapp-gpt) code.

## Star History

[![Star History Chart](https://api.star-history.com/svg?repos=llm-workflow-engine/llm-workflow-engine&type=Date)](https://star-history.com/#llm-workflow-engine/llm-workflow-engine&Date)
